@@ -24,9 +24,10 @@ use Net::LDAP::Constant qw(
   LDAP_CONTROL_SYNC_STATE
   LDAP_CONTROL_SYNC_DONE
   LDAP_CONTROL_ASSERTION
+  LDAP_CONTROL_RELAX
 );
 
-our $VERSION = '0.13';
+our $VERSION = '0.16';
 
 my %Pkg2Type = (
 
@@ -57,6 +58,7 @@ my %Pkg2Type = (
   'Net::LDAP::Control::SyncState'	=> LDAP_CONTROL_SYNC_STATE,
   'Net::LDAP::Control::SyncDone'	=> LDAP_CONTROL_SYNC_DONE,
   'Net::LDAP::Control::Assertion'	=> LDAP_CONTROL_ASSERTION,
+  'Net::LDAP::Control::Relax'		=> LDAP_CONTROL_RELAX,
   #
   #LDAP_CONTROL_PWEXPIRED
   #LDAP_CONTROL_PWEXPIRING
@@ -154,27 +156,35 @@ Net::LDAP::Control - LDAPv3 control object base class
 =head1 SYNOPSIS
 
  use Net::LDAP::Control;
- use Net::LDAP::Constant qw( LDAP_CONTROL_MATCHEDVALS );
+ use Net::LDAP::Constant qw( LDAP_CONTROL_MANAGEDSAIT );
 
- $ctrl = Net::LDAP::Control->new(
+ my $req_ctrl1 = Net::LDAP::Control->new( type => LDAP_CONTROL_MANAGEDSAIT );
+ my $req_ctrl2 = Net::LDAP::Control->new(
    type     => "1.2.3.4",
    value    => "help",
    critical => 0
  );
 
- $mesg = $ldap->search( @args, control => [ $ctrl ]);
+ $mesg = $ldap->search( @args, control => [ $req_ctrl1, $req_ctrl2 ]);
 
- $ctrl = Net::LDAP::Control->new( type => LDAP_CONTROL_MATCHEDVALS );
+ my @res_ctrls = $mesg->control();
 
 =head1 DESCRIPTION
 
-C<Net::LDAP::Control> is a base-class for LDAPv3 control objects.
+C<Net::LDAP::Control> is the base-class for LDAPv3 control objects.
 
-=cut
+Controls provide a mechanism that allows to extend the semantics and
+arguments of LDAP operations.
+Controls may be attached to LDAP operations, and only affect the semantics
+of the operation they are attached to.
 
-##
-## Need more blurb in here about controls
-##
+Controls sent by clients are termed I<request controls>, and are set using
+the C<control> option of the respective LDAP operations.
+Controls sent by servers are called I<response controls>, they can be found
+using the C<control()> method of the response message objects.
+
+Servers announce the controls they support in the attribute C<supportedControls>
+in their L<RootDSE|Net::LDAP::RootDSE>.
 
 =head1 CONSTRUCTORS
 
@@ -188,7 +198,7 @@ ARGS is a list of name/value pairs, valid arguments are:
 
 =item critical
 
-A boolean value, if TRUE and the control is unrecognized by the server or
+A Boolean value, if TRUE and the control is unrecognized by the server or
 is inappropriate for the requested operation then the server will return
 an error and the operation will not be performed.
 
@@ -205,9 +215,9 @@ A dotted-decimal representation of an OBJECT IDENTIFIER which
 uniquely identifies the control. This prevents conflicts between
 control names.
 
-This may be omitted if the contructor is being called on a sub-class of
+This may be omitted if the constructor is being called on a sub-class of
 Net::LDAP::Control which has registered to be associated with an OID.
-If the contructor is being called on the Net::LDAP::Control
+If the constructor is being called on the Net::LDAP::Control
 package, then this argument must be given.  If the given OID has been
 registered by a package, then the returned object will be of the type
 registered to handle that OID.
@@ -249,7 +259,7 @@ return C<undef>
 
 =item init ()
 
-C<init> will be called as the last step in both contructors. What it does will depend
+C<init> will be called as the last step in both constructors. What it does will depend
 on the sub-class. It must always return the object.
 
 =item register ( OID )
@@ -298,23 +308,25 @@ for this method is to return TRUE if there is no error, but sub-classes may over
 
 =head1 SEE ALSO
 
-L<Net::LDAP>
-L<Net::LDAP::Control::Assertion>
-L<Net::LDAP::Control::EntryChange>
-L<Net::LDAP::Control::ManageDsaIT>
-L<Net::LDAP::Control::MatchedValues>
-L<Net::LDAP::Control::Paged>
-L<Net::LDAP::Control::PasswordPolicy>
-L<Net::LDAP::Control::PersistentSearch>
-L<Net::LDAP::Control::PostRead>
-L<Net::LDAP::Control::PreRead>
-L<Net::LDAP::Control::ProxyAuth>
-L<Net::LDAP::Control::Sort>
-L<Net::LDAP::Control::SortResult>
-L<Net::LDAP::Control::SyncDone>
-L<Net::LDAP::Control::SyncRequest>
-L<Net::LDAP::Control::SyncState>
-L<Net::LDAP::Control::VLV>
+L<Net::LDAP>,
+L<Net::LDAP::RootDSE>,
+L<Net::LDAP::Control::Assertion>,
+L<Net::LDAP::Control::EntryChange>,
+L<Net::LDAP::Control::ManageDsaIT>,
+L<Net::LDAP::Control::MatchedValues>,
+L<Net::LDAP::Control::Paged>,
+L<Net::LDAP::Control::PasswordPolicy>,
+L<Net::LDAP::Control::PersistentSearch>,
+L<Net::LDAP::Control::PostRead>,
+L<Net::LDAP::Control::PreRead>,
+L<Net::LDAP::Control::ProxyAuth>,
+L<Net::LDAP::Control::Relax>,
+L<Net::LDAP::Control::Sort>,
+L<Net::LDAP::Control::SortResult>,
+L<Net::LDAP::Control::SyncDone>,
+L<Net::LDAP::Control::SyncRequest>,
+L<Net::LDAP::Control::SyncState>,
+L<Net::LDAP::Control::VLV>,
 L<Net::LDAP::Control::VLVResponse>
 
 =head1 AUTHOR
