@@ -5,7 +5,6 @@
 package Net::LDAP::LDIF;
 
 use strict;
-use SelectSaver;
 require Net::LDAP::Entry;
 
 use constant CHECK_UTF8 => $] > 5.007;
@@ -15,21 +14,22 @@ BEGIN {
     if (CHECK_UTF8);
 }
 
-our $VERSION = '0.20';
+our $VERSION = '0.23';
 
-# allow the letters r,w,a as well as the well-known operators as modes
-my %mode = qw(r < < < w > > > a >> >> >>);
+# allow the letters r,w,a as mode letters
+my %modes = qw(r <  r+ +<  w >  w+ +>  a >>  a+ +>>);
 
 sub new {
   my $pkg = shift;
   my $file = shift || '-';
-  my $mode = shift || 'r';
+  my $mode = @_ % 2 ? shift || 'r' : 'r';
   my %opt = @_;
   my $fh;
   my $opened_fh = 0;
 
-  # harmonize mode, default to reading
-  $mode = $mode{$mode} || '<';
+  # harmonize mode
+  $mode = $modes{$mode}
+    if (defined($modes{$mode}));
 
   if (ref($file)) {
     $fh = $file;
@@ -39,10 +39,13 @@ sub new {
       ($file,$fh) = ($mode eq '<')
                     ? ('STDIN', \*STDIN)
                     : ('STDOUT',\*STDOUT);
+
+      if ($mode =~ /(:.*$)/) {
+        my $layer = $1;
+        binmode($file, $layer);
+      }
     }
     else {
-      require Symbol;
-      $fh = Symbol::gensym();
       $opened_fh = ($file =~ /^\| | \|$/x)
                    ? open($fh, $file)
                    : open($fh, $mode, $file);
@@ -51,10 +54,10 @@ sub new {
   }
 
   # Default the encoding of DNs to 'none' unless the user specifies
-  $opt{encode} = 'none'  unless exists $opt{encode};
+  $opt{encode} = 'none'  unless (exists $opt{encode});
 
   # Default the error handling to die
-  $opt{onerror} = 'die'  unless exists $opt{onerror};
+  $opt{onerror} = 'die'  unless (exists $opt{onerror});
 
   # sanitize options
   $opt{lowercase} ||= 0;
@@ -71,15 +74,9 @@ sub new {
     file => "$file",
     opened_fh => $opened_fh,
     _eof => 0,
-    write_count => ($mode eq '>>' and tell($fh) > 0) ? 1 : 0,
+    write_count => ($mode =~ /^\s*\+?>>/ and tell($fh) > 0) ? 1 : 0,
   };
 
-  # fetch glob for URL type attributes (one per LDIF object)
-  if ($mode eq 'r') {
-    require Symbol;
-    $self->{_attr_fh} = Symbol::gensym();
-  }
-
   bless $self, $pkg;
 }
 
@@ -142,26 +139,46 @@ sub _read_url_attribute {
   my $line;
 
   if ($url =~ s/^file:(?:\/\/)?//) {
-    my $fh = $self->{_attr_fh};
-    unless (open($fh, '<'.$url)) {
-      $self->_error("can't open $line: $!", @ldif);
-      return;
-    }
+    open(my $fh, '<', $url)
+      or  return $self->_error("can't open $url: $!", @ldif);
+
     binmode($fh);
     { # slurp in whole file at once
       local $/;
       $line = <$fh>;
     }
     close($fh);
-  } else {
-    $self->_error('unsupported URL type', @ldif);
-    return;
+  }
+  else {
+    return $self->_error('unsupported URL type', @ldif);
   }
 
   $line;
 }
 
 
+# read attribute value (decode it based in its type)
+sub _read_attribute_value {
+  my $self = shift;
+  my $type = shift;
+  my $value = shift;
+  my @ldif = @_;
+
+  # Base64-encoded value: decode it
+  if ($type && $type eq ':') {
+    require MIME::Base64;
+    $value = MIME::Base64::decode($value);
+  }
+  # URL value: read in file:// URL, fail on others
+  elsif ($type && $type eq '<' and $value =~ s/^(.*?)\s*$/$1/) {
+    $value = $self->_read_url_attribute($value, @ldif);
+    return  if (!defined($value));
+  }
+
+  $value;
+}
+
+
 # _read_one() is deprecated and will be removed
 # in a future version
 *_read_one = \&_read_entry;
@@ -182,28 +199,20 @@ sub _read_entry {
     $self->{version} = $1;
     shift @ldif;
     return $self->_read_entry
-      unless @ldif;
+      unless (@ldif);
   }
 
   if (@ldif < 1) {
-     $self->_error('LDIF entry is not valid', @ldif);
-     return;
+     return $self->_error('LDIF entry is not valid', @ldif);
   }
-  elsif (not ( $ldif[0] =~ s/^dn:(:?) *//) ) {
-     $self->_error('First line of LDIF entry does not begin with "dn:"', @ldif);
-     return;
+  elsif ($ldif[0] !~ /^dn::? */) {
+     return $self->_error('First line of LDIF entry does not begin with "dn:"', @ldif);
   }
 
   my $dn = shift @ldif;
+  my $xattr = $1  if ($dn =~ s/^dn:(:?) *//);
 
-  if (length($1)) {	# $1 is the optional colon from above
-    eval { require MIME::Base64 };
-    if ($@) {
-      $self->_error($@, @ldif);
-      return;
-    }
-    $dn = MIME::Base64::decode($dn);
-  }
+  $dn = $self->_read_attribute_value($xattr, $dn, @ldif);
 
   my $entry = Net::LDAP::Entry->new;
   $dn = Encode::decode_utf8($dn)
@@ -218,24 +227,13 @@ sub _read_entry {
 
     if ($control =~ /^control:\s*(\d+(?:\.\d+)*)(?:\s+(true|false))?(?:\s*\:(.*))?$/) {
       my($oid,$critical,$value) = ($1,$2,$3);
-      my $prefix = $1  if (defined($value) && $value =~ s/^([\<\:])\s*//);
+      my $type = $1  if (defined($value) && $value =~ s/^([\<\:])\s*//);
 
       $critical = ($critical && $critical =~ /true/) ? 1 : 0;
 
-      # base64 encoded value: decode it
-      if ($prefix && $prefix eq ':') {
-        eval { require MIME::Base64 };
-        if ($@) {
-          $self->_error($@, @ldif);
-          return;
-        }
-        $value = MIME::Base64::decode($value);
-      }
-      # url value: read in file:// url, fail on others
-      elsif ($prefix && $prefix eq '<' and $value =~ s/^(.*?)\s*$/$1/) {
-        $value = $self->_read_url_attribute($value, @ldif);
-        return  if !defined($value);
-      }
+      $value = $self->_read_attribute_value($type, $value, @ldif)
+        if (defined($value) && $type);
+      return  if !defined($value);
 
       require Net::LDAP::Control;
       my $ctrl = Net::LDAP::Control->new(type     => $oid,
@@ -244,154 +242,118 @@ sub _read_entry {
 
       push(@controls, $ctrl);
 
-      if (!@ldif) {
-        $self->_error('Illegally formatted control line given', @ldif);
-        return;
-      }
+      return $self->_error('Illegally formatted control line given', @ldif)
+        if (!@ldif);
     }
     else {
-      $self->_error('Illegally formatted control line given', @ldif);
-      return;
+      return $self->_error('Illegally formatted control line given', @ldif);
     }
   }
 
+  # LDIF change record
   if ((scalar @ldif) && ($ldif[0] =~ /^changetype:\s*/)) {
     my $changetype = $ldif[0] =~ s/^changetype:\s*//
         ? shift(@ldif) : $self->{changetype};
     $entry->changetype($changetype);
 
-    return $entry  if ($changetype eq 'delete');
-
-    unless (@ldif) {
-      $self->_error('LDAP entry is not valid', @ldif);
-      return;
+    if ($changetype eq 'delete') {
+      return $self->_error('LDIF "delete" entry is not valid', @ldif)
+        if (@ldif);
+      return $entry;
     }
 
-    while(@ldif) {
-      my $modify = $self->{modify};
+    return $self->_error('LDAP entry is not valid', @ldif)
+      unless (@ldif);
+
+    while (@ldif) {
+      my $action = $self->{modify};
       my $modattr;
       my $lastattr;
-      if($changetype eq 'modify') {
-        unless ( (my $tmp = shift @ldif) =~ s/^(add|delete|replace|increment):\s*([-;\w]+)// ) {
-          $self->_error('LDAP entry is not valid', @ldif);
-          return;
+      my @values;
+
+      if ($changetype eq 'modify') {
+        unless ((my $tmp = shift @ldif) =~ s/^(add|delete|replace|increment):\s*([-;\w]+)//) {
+          return $self->_error('LDAP entry is not valid', @ldif);
         }
         $lastattr = $modattr = $2;
-        $modify  = $1;
+        $action = $1;
       }
-      my @values;
-      while(@ldif) {
+
+      while (@ldif) {
         my $line = shift @ldif;
-        my $attr;
-	my $xattr;
 
         if ($line eq '-') {
-          if (defined $lastattr) {
-	    if (CHECK_UTF8 && $self->{raw}) {
-  	      map { $_ = Encode::decode_utf8($_) } @values
-	        if ($lastattr !~ /$self->{raw}/);
-	    }
-            $entry->$modify($lastattr, \@values);
-	  }
-          undef $lastattr;
-          @values = ();
+          return $self->_error('LDAP entry is not valid', @ldif)
+            if (!defined($modattr) || !defined($lastattr));
+
           last;
         }
 
-        $line =~ s/^([-;\w]+):([\<\:]?)\s*// and
-	    ($attr, $xattr) = ($1, $2);
+        if ($line =~ /^([-;\w]+):([\<\:]?)\s*(.*)$/o) {
+          my ($attr,$xattr,$val) = ($1,$2,$3);
 
-        # base64 encoded attribute: decode it
-        if ($xattr eq ':') {
-          eval { require MIME::Base64 };
-          if ($@) {
-            $self->_error($@, @ldif);
-            return;
+          return $self->_error('LDAP entry is not valid', @ldif)
+            if (defined($modattr) && $attr ne $modattr);
+
+          $val = $self->_read_attribute_value($xattr, $val, $line)
+            if ($xattr);
+          return  if !defined($val);
+
+          $val = Encode::decode_utf8($val)
+            if (CHECK_UTF8 && $self->{raw} && ($attr !~ /$self->{raw}/));
+
+          if (!defined($lastattr) || $lastattr ne $attr) {
+            $entry->$action($lastattr => \@values)
+              if (defined $lastattr);
+
+            $lastattr = $attr;
+            @values = ();
           }
-          $line = MIME::Base64::decode($line);
+          push(@values, $val);
         }
-        # url attribute: read in file:// url, fail on others
-        elsif ($xattr eq '<' and $line =~ s/^(.*?)\s*$/$1/) {
-          $line = $self->_read_url_attribute($line, @ldif);
-          return  if !defined($line);
+        else {
+          return $self->_error('LDAP entry is not valid', @ldif);
         }
-
-        if( defined($modattr) && $attr ne $modattr ) {
-          $self->_error('LDAP entry is not valid', @ldif);
-          return;
-        }
-
-        if(!defined($lastattr) || $lastattr ne $attr) {
-          if (defined $lastattr) {
-	    if (CHECK_UTF8 && $self->{raw}) {
-  	      map { $_ = Encode::decode_utf8($_) } @values
-	        if ($lastattr !~ /$self->{raw}/);
-	    }
-            $entry->$modify($lastattr, \@values);
-	  }
-          $lastattr = $attr;
-          @values = ($line);
-          next;
-        }
-        push @values, $line;
-      }
-      if (defined $lastattr) {
-        if (CHECK_UTF8 && $self->{raw}) {
-  	  map { $_ = Encode::decode_utf8($_) } @values
-	    if ($lastattr !~ /$self->{raw}/);
-        }
-        $entry->$modify($lastattr, \@values);
       }
+      $entry->$action($lastattr => \@values)
+        if (defined $lastattr);
     }
   }
-
+  # content record (i.e. no 'changetype' line; implicitly treated as 'add')
   else {
-    my @attr;
     my $last = '';
-    my $vals = [];
-    my $attr;
-    my $xattr;
+    my @values;
 
-    if (@controls) {
-      $self->_error("Controls only allowed with LDIF change entries", @ldif);
-      return;
-    }
+    return $self->_error('Controls only allowed with LDIF change entries', @ldif)
+      if (@controls);
 
     foreach my $line (@ldif) {
-      $line =~ s/^([-;\w]+):([\<\:]?)\s*// &&
-	  (($attr, $xattr) = ($1, $2)) or next;
+      if ($line =~ /^([-;\w]+):([\<\:]?)\s*(.*)$/o) {
+        my($attr,$xattr,$val) = ($1,$2,$3);
 
-      # base64 encoded attribute: decode it
-      if ($xattr eq ':') {
-        eval { require MIME::Base64 };
-        if ($@) {
-          $self->_error($@, @ldif);
-          return;
+        $last = $attr  if (!$last);
+
+        $val = $self->_read_attribute_value($xattr, $val, $line)
+          if ($xattr);
+        return  if !defined($val);
+
+        $val = Encode::decode_utf8($val)
+          if (CHECK_UTF8 && $self->{raw} && ($attr !~ /$self->{raw}/));
+
+        if ($attr ne $last) {
+          $entry->add($last => \@values);
+          @values = ();
+          $last = $attr;
         }
-        $line = MIME::Base64::decode($line);
-      }
-      # url attribute: read in file:// url, fail on others
-      elsif ($xattr eq '<' and $line =~ s/^(.*?)\s*$/$1/) {
-        $line = $self->_read_url_attribute($line, @ldif);
-        return  if !defined($line);
-      }
-
-      if (CHECK_UTF8 && $self->{raw}) {
-        $line = Encode::decode_utf8($line)
-          if ($attr !~ /$self->{raw}/);
-      }
-
-      if ($attr eq $last) {
-        push @$vals, $line;
-        next;
+        push(@values, $val);
       }
       else {
-        $vals = [$line];
-        push(@attr, $last=$attr, $vals);
+        return $self->_error("illegal LDIF line '$line'", @ldif);
       }
     }
-    $entry->add(@attr);
+    $entry->add($last => \@values);
   }
+
   $self->{_current_entry} = $entry;
 
   $entry;
@@ -400,10 +362,9 @@ sub _read_entry {
 sub read_entry {
   my $self = shift;
 
-  unless ($self->{fh}) {
-     $self->_error('LDIF file handle not valid');
-     return;
-  }
+  return $self->_error('LDIF file handle not valid')
+    unless ($self->{fh});
+
   $self->_read_entry();
 }
 
@@ -415,7 +376,7 @@ sub read {
   return $self->read_entry()  unless wantarray;
 
   my($entry, @entries);
-  push(@entries, $entry)  while $entry = $self->read_entry;
+  push(@entries, $entry)  while ($entry = $self->read_entry);
 
   @entries;
 }
@@ -424,25 +385,26 @@ sub eof {
   my $self = shift;
   my $eof = shift;
 
-  if ($eof) {
-    $self->{_eof} = $eof;
-  }
+  $self->{_eof} = $eof
+    if ($eof);
 
   $self->{_eof};
 }
 
 sub _wrap {
-  my $len=$_[1];	# needs to be >= 2 to avoid division by zero
-  return $_[0]  if length($_[0]) <= $len or $len <= 40;
+  my $len = int($_[1]);	# needs to be >= 2 to avoid division by zero
+  return $_[0]  if (length($_[0]) <= $len or $len <= 40);
   use integer;
-  my $l2 = $len-1;
+  my $l2 = $len - 1;
   my $x = (length($_[0]) - $len) / $l2;
   my $extra = (length($_[0]) == ($l2 * $x + $len)) ? '' : 'a*';
   join("\n ", unpack("a$len" . "a$l2" x $x . $extra, $_[0]));
 }
 
 sub _write_attr {
-  my($attr, $val, $wrap, $lower) = @_;
+  my($self, $attr, $val) = @_;
+  my $lower = $self->{lowercase};
+  my $fh = $self->{fh};
   my $res = 1;	# result value
 
   foreach my $v (@$val) {
@@ -450,6 +412,7 @@ sub _write_attr {
 
     $v = Encode::encode_utf8($v)
       if (CHECK_UTF8 and Encode::is_utf8($v));
+
     if ($v =~ /(^[ :<]|[\x00-\x1f\x7f-\xff]| $)/) {
       require MIME::Base64;
       $ln .= ':: ' . MIME::Base64::encode($v, '');
@@ -457,7 +420,7 @@ sub _write_attr {
     else {
       $ln .= ': ' . $v;
     }
-    $res &&= print _wrap($ln, $wrap), "\n";
+    $res &&= print $fh _wrap($ln, $self->{wrap}), "\n";
   }
   $res;
 }
@@ -469,23 +432,27 @@ sub _cmpAttrs {
 }
 
 sub _write_attrs {
-  my($entry, $wrap, $lower, $sort) = @_;
+  my($self, $entry) = @_;
   my @attributes = $entry->attributes();
   my $res = 1;	# result value
 
-  @attributes = sort _cmpAttrs @attributes  if ($sort);
+  @attributes = sort _cmpAttrs @attributes  if ($self->{sort});
+
   foreach my $attr (@attributes) {
     my $val = $entry->get_value($attr, asref => 1);
-    $res &&= _write_attr($attr, $val, $wrap, $lower);
+    $res &&= $self->_write_attr($attr, $val);
   }
   $res;
 }
 
 sub _write_dn {
-  my($dn, $encode, $wrap) = @_;
+  my($self, $dn) = @_;
+  my $encode = $self->{encode};
+  my $fh = $self->{fh};
 
   $dn = Encode::encode_utf8($dn)
     if (CHECK_UTF8 and Encode::is_utf8($dn));
+
   if ($dn =~ /^[ :<]|[\x00-\x1f\x7f-\xff]/) {
     if ($encode =~ /canonical/i) {
       require Net::LDAP::Util;
@@ -494,16 +461,19 @@ sub _write_dn {
       # are special in LDIF, so we fix those up here.
       $dn =~ s/^([ :<])/\\$1/;
       $dn = "dn: $dn";
-    } elsif ($encode =~ /base64/i) {
+    }
+    elsif ($encode =~ /base64/i) {
       require MIME::Base64;
       $dn = 'dn:: ' . MIME::Base64::encode($dn, '');
-    } else {
+    }
+    else {
       $dn = "dn: $dn";
     }
-  } else {
+  }
+  else {
     $dn = "dn: $dn";
   }
-  print _wrap($dn, $wrap), "\n";
+  print $fh _wrap($dn, $self->{wrap}), "\n";
 }
 
 # write() is deprecated and will be removed
@@ -522,9 +492,10 @@ sub write_entry {
 
 sub write_version {
   my $self = shift;
+  my $fh = $self->{fh};
   my $res = 1;
 
-  $res &&= print "version: $self->{version}\n"
+  $res &&= print $fh "version: $self->{version}\n"
     if ($self->{version} && !$self->{version_written}++);
 
   return $res;
@@ -534,19 +505,13 @@ sub write_version {
 sub _write_entry {
   my $self = shift;
   my $change = shift;
-  my $wrap = int($self->{wrap});
-  my $lower = $self->{lowercase};
-  my $sort = $self->{sort};
+  my $fh = $self->{fh};
   my $res = 1;	# result value
   local($\, $,); # output field and record separators
 
-  unless ($self->{fh}) {
-     $self->_error('LDIF file handle not valid');
-     return;
-  }
-  my $saver = SelectSaver->new($self->{fh});
+  return $self->_error('LDIF file handle not valid')
+    unless ($fh);
 
-  my $fh = $self->{fh};
   foreach my $entry (@_) {
     unless (ref $entry) {
        $self->_error("Entry '$entry' is not a valid Net::LDAP::Entry object.");
@@ -559,56 +524,53 @@ sub _write_entry {
       my $type = $entry->changetype;
 
       # Skip entry if there is nothing to write
-      next  if $type eq 'modify' and !@changes;
+      next  if ($type eq 'modify' and !@changes);
 
-      $res &&= $self->write_version()  unless $self->{write_count}++;
-      $res &&= print "\n";
-      $res &&= _write_dn($entry->dn, $self->{encode}, $wrap);
+      $res &&= $self->write_version()  unless ($self->{write_count}++);
+      $res &&= print $fh "\n";
+      $res &&= $self->_write_dn($entry->dn);
 
-      $res &&= print "changetype: $type\n";
+      $res &&= print $fh "changetype: $type\n";
 
       if ($type eq 'delete') {
         next;
       }
       elsif ($type eq 'add') {
-        $res &&= _write_attrs($entry, $wrap, $lower, $sort);
+        $res &&= $self->_write_attrs($entry);
         next;
       }
       elsif ($type =~ /modr?dn/o) {
         my $deleteoldrdn = $entry->get_value('deleteoldrdn') || 0;
-        $res &&= _write_attr('newrdn', $entry->get_value('newrdn', asref => 1), $wrap, $lower);
-        $res &&= print 'deleteoldrdn: ', $deleteoldrdn, "\n";
+        $res &&= $self->_write_attr('newrdn', $entry->get_value('newrdn', asref => 1));
+        $res &&= print $fh 'deleteoldrdn: ', $deleteoldrdn, "\n";
         my $ns = $entry->get_value('newsuperior', asref => 1);
-        $res &&= _write_attr('newsuperior', $ns, $wrap, $lower)  if defined $ns;
+        $res &&= $self->_write_attr('newsuperior', $ns)  if (defined $ns);
         next;
       }
 
-      my $dash=0;
-      foreach my $chg (@changes) {
-        unless (ref($chg)) {
-          $type = $chg;
-          next;
-        }
-        my $i = 0;
-        while ($i < @$chg) {
-	  $res &&= print "-\n"  if (!$self->{version} && $dash++);
-          my $attr = $chg->[$i++];
-          my $val = $chg->[$i++];
-          $res &&= print $type, ': ', $attr, "\n";
-          $res &&= _write_attr($attr, $val, $wrap, $lower);
-	  $res &&= print "-\n"  if ($self->{version});
+      my $dash = 0;
+      # changetype: modify
+      while (my($action,$attrs) = splice(@changes, 0, 2)) {
+        my @attrs = @$attrs;
+
+        while (my($attr,$val) = splice(@attrs, 0, 2)) {
+          $res &&= print $fh "-\n"  if (!$self->{version} && $dash++);
+          $res &&= print $fh "$action: $attr\n";
+          $res &&= $self->_write_attr($attr, $val);
+          $res &&= print $fh "-\n"  if ($self->{version});
         }
       }
     }
-
     else {
-      $res &&= $self->write_version()  unless $self->{write_count}++;
-      $res &&= print "\n";
-      $res &&= _write_dn($entry->dn, $self->{encode}, $wrap);
-      $res &&= _write_attrs($entry, $wrap, $lower, $sort);
+      $res &&= $self->write_version()  unless ($self->{write_count}++);
+      $res &&= print $fh "\n";
+      $res &&= $self->_write_dn($entry->dn);
+      $res &&= $self->_write_attrs($entry);
     }
   }
 
+  $self->_error($!)  if (!$res && $!);
+
   $res;
 }
 
@@ -620,7 +582,7 @@ sub read_cmd {
   return $self->read_entry()  unless wantarray;
 
   my($entry, @entries);
-  push(@entries, $entry)  while $entry = $self->read_entry;
+  push(@entries, $entry)  while ($entry = $self->read_entry);
 
   @entries;
 }
@@ -640,12 +602,13 @@ sub write_cmd {
 sub done {
   my $self = shift;
   my $res = 1;	# result value
+
   if ($self->{fh}) {
-     if ($self->{opened_fh}) {
-       $res = close $self->{fh};
-       undef $self->{opened_fh};
-     }
-     delete $self->{fh};
+    if ($self->{opened_fh}) {
+      $res = close($self->{fh});
+      undef $self->{opened_fh};
+    }
+    delete $self->{fh};
   }
   $res;
 }
@@ -671,16 +634,19 @@ my %onerror = (
   undef => sub {
                 my $self = shift;
                 require Carp;
-                Carp::carp($self->error(@_))  if $^W;
+                Carp::carp($self->error(@_))  if ($^W);
              },
 );
 
 sub _error {
-   my ($self, $errmsg, @errlines) = @_;
-   $self->{_err_msg} = $errmsg;
-   $self->{_err_lines} = join "\n", @errlines;
+  my ($self, $errmsg, @errlines) = @_;
+  $self->{_err_msg} = $errmsg;
+  $self->{_err_lines} = join("\n", @errlines);
 
-   scalar &{ $onerror{ $self->{onerror} } }($self, $self->{_err_msg})  if $self->{onerror};
+  scalar &{ $onerror{ $self->{onerror} } }($self, $self->{_err_msg})
+    if ($self->{onerror});
+
+  return;
 }
 
 sub _clear_error {
@@ -712,7 +678,7 @@ sub current_lines {
 
 sub version {
   my $self = shift;
-  return $self->{version}  unless @_;
+  return $self->{version}  unless (@_);
   $self->{version} = shift || 0;
 }
 
